@@ -1,9 +1,10 @@
 from orderlyweb_api.orderly_web_api import OrderlyWebAPI
 from orderlyweb_api.orderly_web_response_error import OrderlyWebResponseError
-from orderlyweb_api.report_status_result import ReportStatusResult
+from orderlyweb_api.result_models import ReportStatusResult, VersionDetails
 
 __all__ = [
     OrderlyWebAPI,
     OrderlyWebResponseError,
-    ReportStatusResult
+    ReportStatusResult,
+    VersionDetails
 ]
