@@ -40,7 +40,7 @@ def test_kill_report():
     key = api.run_report('minimal', {}, 500)
     api.kill_report(key)
     result = api.report_status(key)
-    assert result.status == "killed"
+    assert result.status == "interrupted"
 
 
 def test_run_report():
@@ -84,9 +84,7 @@ def test_report_status():
     key = api.run_report('minimal', {}, 500)
     result = api.report_status(key)
     assert result.status == "queued"
-    assert result.version is None
-    assert len(result.output["stderr"]) == 0
-    assert len(result.output["stdout"]) > 0
+    assert result.output is None
     assert not result.success
     assert not result.fail
     assert not result.finished
@@ -107,3 +105,20 @@ def test_run_report_to_completion():
     assert not result.fail
     assert len(result.version) > 0
     assert result.output is None
+
+
+def test_run_report_with_params_to_completion():
+    api = OrderlyWebAPI(base_url, montagu_token)
+    key = api.run_report('other', {'nmin': 0}, 500)
+    finished = False
+    timeout = datetime.now() + timedelta(minutes=1)
+    while not finished and datetime.now() < timeout:
+        time.sleep(0.5)
+        result = api.report_status(key)
+        finished = result.finished
+    assert result.status == "success"
+    assert result.finished
+    assert result.success
+    assert not result.fail
+    assert len(result.version) > 0
+    assert result.output is None
