@@ -4,9 +4,9 @@ import requests_mock
 import pytest
 
 base_url = 'http://test'
-api_base_url = base_url + "/api/v1/"
+api_base_url = base_url + "/api/v2/"
 error_response_text = '{"errors": ' + \
-                      '[{"message": "test-err-msg"}]' + \
+                      '[{"detail": "test-err-msg"}]' + \
                       '}'
 
 
@@ -44,7 +44,7 @@ def test_run_report():
         assert key == "test-key"
 
         request = m.request_history[0]
-        assert request.body == "{'p1': 'v1', 'p2': 2}"
+        assert request.body == "{\"params\": {\"p1\": \"v1\", \"p2\": 2}}"
 
 
 def test_run_report_error():
